@@ -2,13 +2,17 @@
 Date         : 2023-11-02 12:44:48
 Author       : BDFD,bdfd2005@gmail.com
 Github       : https://github.com/bdfd
-LastEditTime : 2023-11-13 15:42:46
-LastEditors  : BDFD
+LastEditTime : 2024-04-05 12:12:02
+LastEditors  : <BDFD>
 Description  : 
 FilePath     : \execdata\graph\__init__.py
 Copyright (c) 2023 by BDFD, All Rights Reserved. 
 '''
 
 from ._data_analysis_graph import top_correlation
+from ._data_analysis_graph import count_plot_graph
+from ._data_analysis_graph import box_plot_graph
+
 from ._data_mining_graph import missing_value_analysis
-from ._linear_regression_type_graph import discrete_feature_graph
\ No newline at end of file
+
+from ._linear_regression_type_graph import discrete_feature_graph
